@@ -2,7 +2,7 @@
 
 import vtk
 from ladybug.color import Colorset, Color
-from enum import Enum, auto
+from enum import Enum
 from typing import Tuple, Union, List
 from ._helper import _validate_input
 
@@ -37,10 +37,10 @@ class ColorSets(Enum):
     black_to_white = 'black_to_white'
     blue_green_red = 'blue_green_red'
     cloud_cover = 'cloud_cover'
-    cold_sensation = 'cloud_sensation'
+    cold_sensation = 'cold_sensation'
     ecotect = 'ecotect'
     energy_balance = 'energy_balance'
-    energy_balance_storage = 'energy_balance_storag'
+    energy_balance_storage = 'energy_balance_storage'
     glare_study = 'glare_study'
     harm = 'harm'
     heat_sensation = 'heat_sensation'
@@ -188,6 +188,8 @@ class LegendParameter:
             unit: A text string representing the unit of the data that the legend
                 represents. Examples are 'celsius', 'kwn/m2', etc.
             colorset: A ColorSet object. Defaults to Ecotect colorset.
+            reverse_colorset: A boolean to specify whether the colorset should be
+                reversed. Defaults to False.
             hide_legend: A boolean to set the visibility of a legend in Scene.
                 Defaults to False.
             orientation: An Orientation object that sets the orientation of the legend in
@@ -213,7 +215,7 @@ class LegendParameter:
             decimal_count: A DecimalCount object that specifies the number of decimals
                 on each label of the legend. Defaults to the type of data. For data
                 with integer values this will default to integer. Similarly, for data
-                with decimal values, this will default to decimal point numbers. 
+                with decimal values, this will default to decimal point numbers.
             preceding_labels: A boolean value to indicate whether the title and the
                 labels should precede the legend or not. Defaults to False.
             label_parameters: A Text object. Defaults to size 30 black text.
@@ -222,7 +224,7 @@ class LegendParameter:
                 Defaults to None.
             min: A number that will be set as the upper bound of the legend.
                 Defaults to None.
-            auto_range: A tuple of minimum and maximum values for legend. This is 
+            auto_range: A tuple of minimum and maximum values for legend. This is
                 auto set when Data is loaded on a model. Use min and max arguments to
                 customize this auto calculated range.
         """
@@ -232,6 +234,7 @@ class LegendParameter:
             name: str = 'Legend',
             unit: str = '',
             colorset: ColorSets = ColorSets.ecotect,
+            reverse_colorset: bool = False,
             hide_legend: bool = False,
             orientation: Orientation = Orientation.horizontal,
             position: Tuple[float, float] = (0.5, 0.1),
@@ -250,6 +253,7 @@ class LegendParameter:
         self.name = name
         self.unit = unit
         self.colorset = colorset
+        self.reverse_colorset = reverse_colorset
         self.hide_legend = hide_legend
         self.orientation = orientation
         self.position = position
@@ -314,6 +318,22 @@ class LegendParameter:
                 f'A ColorSet objects expected. Instead got {val}.'
             )
 
+    @property
+    def reverse_colorset(self) -> bool:
+        """A boolean to specify whether the colorset should be reversed."""
+        return self._reverse_colorset
+
+    @reverse_colorset.setter
+    def reverse_colorset(self, val) -> None:
+        if not val:
+            self._reverse_colorset = False
+        elif isinstance(val, bool):
+            self._reverse_colorset = val
+        else:
+            raise ValueError(
+                f'A boolean value expected. Instead got {val}.'
+            )
+
     @property
     def hide_legend(self) -> bool:
         """Visibility of legend in the scene."""
@@ -511,7 +531,7 @@ class LegendParameter:
 
     @min.setter
     def min(self, val):
-        if val == None:
+        if val is None:
             self._min = None
         elif isinstance(val, (int, float)):
             self._min = val
@@ -526,7 +546,7 @@ class LegendParameter:
 
     @max.setter
     def max(self, val):
-        if val == None:
+        if val is None:
             self._max = None
         elif isinstance(val, (int, float)):
             self._max = val
@@ -537,10 +557,10 @@ class LegendParameter:
 
     @property
     def range(self) -> Tuple[float, float]:
-        if self._min == None and self._max == None:
+        if self._min is None and self._max is None:
             return self.auto_range
 
-        elif self._min and self._max == None:
+        elif self._min and self._max is None:
             if self._min < self.auto_range[1]:
                 return (self._min, self.auto_range[1])
             else:
@@ -551,7 +571,7 @@ class LegendParameter:
                     ' provide a max value.'
                 )
 
-        elif self._min == None and self._max:
+        elif self._min is None and self._max:
             if self._max > self.auto_range[0]:
                 return (self.auto_range[0], self._max)
             else:
@@ -572,11 +592,12 @@ class LegendParameter:
                     f' value {self._min}.'
                 )
 
-    def _assign_colors(self, colors: Tuple[Color, ...]) -> None:
+    def _assign_colors(self, val: List[Color]) -> None:
         """Assign colors instead of a colorset.
 
-        This private method is currently used in generating timestep images.
+        This private method is currently used in to_grid_images method of vtk Model.
         """
+        colors = tuple(val)
         self._colors = colors
         self._color_count = len(colors)
         self.label_count = self._color_count
@@ -587,14 +608,15 @@ class LegendParameter:
         This method is only used in the 'translate' command.
         """
         return {
-            'name': self.name,
-            'unit': self.unit,
-            'colors': self.colorset.value,
-            'hide_legend': self.hide_legend,
-            'color_count': self.color_count,
-            'label_count': self.label_count,
-            'min': self.min,
-            'max': self.max,
+            'name': self._name,
+            'unit': self._unit,
+            'colors': self._colorset.value,
+            'reverse_colorset': self._reverse_colorset,
+            'hide_legend': self._hide_legend,
+            'color_count': self._color_count,
+            'label_count': self._label_count,
+            'min': self._min,
+            'max': self._max,
             'range': self.range
         }
 
@@ -603,8 +625,12 @@ class LegendParameter:
         minimum, maximum = self.range
         if not self._colors:
             color_values = color_set[self._colorset.value]
+            if self._reverse_colorset:
+                color_values = list(color_values)
+                color_values.reverse()
         else:
             color_values = self._colors
+
         lut = vtk.vtkLookupTable()
         lut.SetRange(minimum, maximum)
         lut.SetRampToLinear()
@@ -633,6 +659,7 @@ class LegendParameter:
         else:
             scalar_bar.SetTitle(self._name)
 
+        scalar_bar.SetTextPad(2)
         scalar_bar.SetPosition(self._position)
         scalar_bar.SetWidth(self._width)
         scalar_bar.SetHeight(self._height)
@@ -655,6 +682,7 @@ class LegendParameter:
         # Setting whether the labels and title should precede the legend
         scalar_bar.SetTextPosition(self._preceding_labels)
 
+        self._label_parameters.size = round(self._title_parameters.size * 0.8)
         scalar_bar.SetLabelTextProperty(self._label_parameters.to_vtk())
         scalar_bar.SetTitleTextProperty(self._title_parameters.to_vtk())
 
